@@ -3,7 +3,7 @@ from tests.config import db
 from tests.models.user import User
 
 
-def main():
+if __name__ == '__main__':
 
     Database().connect(**db)
 
@@ -21,7 +21,3 @@ def main():
 
     # # case 4
     # User.find().delete()
-
-
-if __name__ == '__main__':
-    main()
