@@ -3,13 +3,9 @@ from tests.config import db
 from tests.models.user import User
 
 
-def main():
+if __name__ == '__main__':
 
     Database().connect(**db)
 
     money = User.find().where(id=1).scalar('money')
     print(money)
-
-
-if __name__ == '__main__':
-    main()
