@@ -3,22 +3,18 @@ from config import db
 from models.user import User
 
 
-def main():
+if __name__ == '__main__':
     Database().connect(**db)
 
-    User.find().truncate()
+    User.truncate()
 
+    fields = ('name', 'phone', 'money')
+    values = []
     fp = open('user.txt', 'r')
     for line in fp:
         line = line.strip('\r\n')
-        name, phone, money = line.split()
-        model = User()
-        model.name = name
-        model.phone = phone
-        model.money = money
-        model.save()
+        value = (name, phone, money) = line.split()
+        values.append(value)
     fp.close()
 
-
-if __name__ == '__main__':
-    main()
+    User.insert(fields, values)
